@@ -84,7 +84,7 @@ static void print_gss_err(const char *where,
 }
 
 const gss_OID_desc spnego_mech = {6, (void *)"\x2b\x06\x01\x05\x05\x02"};
-const gss_OID_set_desc desired_mechs = { 
+const gss_OID_set_desc desired_mechs = {
 	.count = 1,
 	.elements = (gss_OID)&spnego_mech
 };
@@ -93,14 +93,14 @@ static void gssapi_vhost_init(void **_vctx, void *pool, void *additional)
 {
 	int ret;
 	OM_uint32 time, minor;
-	gss_name_t name = GSS_C_NO_NAME;
+	const gss_name_t name = GSS_C_NO_NAME;
 	gssapi_cfg_st *config = additional;
 	struct gssapi_vhost_ctx_st *vctx;
 
 	vctx = talloc_zero(pool, struct gssapi_vhost_ctx_st);
 	if (vctx == NULL) {
 		fprintf(stderr, "auth-gssapi: memory error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	if (config) {
@@ -123,7 +123,7 @@ static void gssapi_vhost_init(void **_vctx, void *pool, void *additional)
 		if (ret != GSS_S_COMPLETE) {
 			ret = -1;
 			print_gss_err("gss_acquire_cred(keytab)", GSS_C_NO_OID, ret, minor);
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 	} else {
 		ret = gss_acquire_cred(&minor, name, 0, (gss_OID_set)&desired_mechs, 2,
@@ -132,13 +132,10 @@ static void gssapi_vhost_init(void **_vctx, void *pool, void *additional)
 		if (ret != GSS_S_COMPLETE) {
 			ret = -1;
 			print_gss_err("gss_acquire_cred", GSS_C_NO_OID, ret, minor);
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 	}
 
-	if (name != GSS_C_NO_NAME)
-		gss_release_name(&minor, &name);
-
 	*_vctx = vctx;
 	return;
 }
@@ -214,7 +211,7 @@ static int verify_krb5_constraints(struct gssapi_ctx_st *pctx, gss_OID mech_type
 		return -1;
 	}
 
-	if (time(0) > authtime + pctx->vctx->ticket_freshness_secs) {
+	if (time(NULL) > authtime + pctx->vctx->ticket_freshness_secs) {
 		syslog(LOG_INFO, "gssapi: the presented kerberos ticket for %s is too old", pctx->username);
 		return -1;
 	}
