@@ -68,7 +68,7 @@ static void plain_vhost_init(void **vctx, void *pool, void *additional)
 
 	if (config == NULL) {
 		fprintf(stderr, "plain: no configuration passed!\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	*vctx = (void*)config;
@@ -158,7 +158,7 @@ static int read_auth_pass(struct plain_ctx_st *pctx)
 
 	fp = fopen(pctx->config->passwd, "r");
 	if (fp == NULL) {
-		syslog(LOG_NOTICE,
+		syslog(LOG_ERR,
 		       "error in plain authentication; cannot open: %s",
 		       pctx->config->passwd);
 		return -1;
@@ -232,7 +232,7 @@ static int plain_auth_init(void **ctx, void *pool, void *vctx, const common_auth
 	int ret;
 
 	if (info->username == NULL || info->username[0] == 0) {
-		syslog(LOG_NOTICE,
+		syslog(LOG_ERR,
 		       "plain-auth: no username present");
 		return ERR_AUTH_FAIL;
 	}
@@ -480,7 +480,7 @@ static void plain_group_list(void *pool, void *additional, char ***groupname, un
 
 	/* always succeed */
  exit:
- 	htable_clear(&hash);
+	htable_clear(&hash);
 	safe_memset(line, 0, sizeof(line));
 	fclose(fp);
 	return;
