@@ -18,8 +18,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>
  */
-#ifndef COMMON_CONFIG_H
-# define COMMON_CONFIG_H
+#ifndef OC_COMMON_CONFIG_H
+# define OC_COMMON_CONFIG_H
 
 #include <config.h>
 #include <vpn.h>
