@@ -75,7 +75,7 @@ struct proc_st *new_proc(main_server_st * s, pid_t pid, int cmd_fd,
 	ctmp->tun_lease.fd = -1;
 	ctmp->fd = cmd_fd;
 	set_cloexec_flag (cmd_fd, 1);
-	ctmp->conn_time = time(0);
+	ctmp->conn_time = time(NULL);
 
 	memcpy(&ctmp->remote_addr, remote_addr, remote_addr_len);
 	ctmp->remote_addr_len = remote_addr_len;
@@ -113,7 +113,7 @@ void remove_proc(main_server_st * s, struct proc_st *proc, unsigned flags)
 	if (proc->active_sid && !(flags & RPROC_QUIT)) {
 		if (session_close(&(s->sec_mod_instances[proc->sec_mod_instance_index]), proc) < 0) {
 			mslog(s, proc, LOG_ERR, "error closing session (communication with sec-mod issue)");
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 	}
 
@@ -127,10 +127,10 @@ void remove_proc(main_server_st * s, struct proc_st *proc, unsigned flags)
 			/* we were called during the connect script being run.
 			 * wait for it to finish and if it returns zero run the
 			 * disconnect script */
-			 if (waitpid(pid, &wstatus, 0) > 0) {
-			 	if (WEXITSTATUS(wstatus) == 0)
+			if (waitpid(pid, &wstatus, 0) > 0) {
+				if (WEXITSTATUS(wstatus) == 0)
 					user_disconnected(s, proc);
-			 }
+			}
 		} else { /* pid > 0 or status == PS_AUTH_COMPLETED are mutually exclusive
 		          * since PS_AUTH_COMPLETED is set only after a successful script run.
 		          */
@@ -158,4 +158,3 @@ void remove_proc(main_server_st * s, struct proc_st *proc, unsigned flags)
 	safe_memset(proc->sid, 0, sizeof(proc->sid));
 	talloc_free(proc);
 }
-
