@@ -73,7 +73,7 @@
 # include <libtasn1.h>
 
 extern const ASN1_ARRAY_TYPE kkdcp_asn1_tab[];
-ASN1_TYPE _kkdcp_pkix1_asn = NULL;
+asn1_node _kkdcp_pkix1_asn = NULL;
 #endif
 
 extern struct snapshot_t * config_snapshot;
@@ -169,7 +169,7 @@ static void set_common_socket_options(int fd)
 	set_cloexec_flag (fd, 1);
 }
 
-static 
+static
 int _listen_ports(void *pool, struct perm_cfg_st* config, struct addrinfo *res,
 		struct listen_list_st *list, struct netns_fds *netns)
 {
@@ -253,7 +253,7 @@ int _listen_ports(void *pool, struct perm_cfg_st* config, struct addrinfo *res,
 /* Returns 0 on success or negative value on error.
  */
 static int
-listen_ports(void *pool, struct perm_cfg_st* config, 
+listen_ports(void *pool, struct perm_cfg_st* config,
 		struct listen_list_st *list,
 		struct netns_fds *netns)
 {
@@ -327,7 +327,7 @@ listen_ports(void *pool, struct perm_cfg_st* config,
 
 		if (list->total == 0) {
 			fprintf(stderr, "no useful sockets were provided by systemd\n");
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 
 		if (config->foreground != 0)
@@ -371,7 +371,7 @@ listen_ports(void *pool, struct perm_cfg_st* config,
 
 	if (list->total == 0) {
 		fprintf(stderr, "Could not listen to any TCP or UNIX ports\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	if (config->udp_port) {
@@ -486,7 +486,7 @@ void clear_lists(main_server_st *s)
 		}
 		ev_timer_stop(main_loop, &maintenance_watcher);
 #if defined(CAPTURE_LATENCY_SUPPORT)
-		ev_timer_stop(main_loop, &latency_watcher);		
+		ev_timer_stop(main_loop, &latency_watcher);
 #endif
 		/* free memory and descriptors by the event loop */
 		ev_loop_destroy (main_loop);
@@ -676,7 +676,7 @@ int sfd = -1;
 
 	/* check version */
 	if (s->msg_buffer[0] == 22) {
-		mslog(s, NULL, LOG_DEBUG, "new DTLS session from %s (record v%u.%u, hello v%u.%u)", 
+		mslog(s, NULL, LOG_DEBUG, "new DTLS session from %s (record v%u.%u, hello v%u.%u)",
 			human_addr((struct sockaddr*)&cli_addr, cli_addr_size, tbuf, sizeof(tbuf)),
 			(unsigned int)s->msg_buffer[1], (unsigned int)s->msg_buffer[2],
 			(unsigned int)s->msg_buffer[RECORD_PAYLOAD_POS], (unsigned int)s->msg_buffer[RECORD_PAYLOAD_POS+1]);
@@ -684,7 +684,7 @@ int sfd = -1;
 
 	if (s->msg_buffer[1] != 254 && (s->msg_buffer[1] != 1 && s->msg_buffer[2] != 0) &&
 		s->msg_buffer[RECORD_PAYLOAD_POS] != 254 && (s->msg_buffer[RECORD_PAYLOAD_POS] != 0 && s->msg_buffer[RECORD_PAYLOAD_POS+1] != 0)) {
-		mslog(s, NULL, LOG_INFO, "%s: unknown DTLS record version: %u.%u", 
+		mslog(s, NULL, LOG_INFO, "%s: unknown DTLS record version: %u.%u",
 		      human_addr((struct sockaddr*)&cli_addr, cli_addr_size, tbuf, sizeof(tbuf)),
 		      (unsigned)s->msg_buffer[1], (unsigned)s->msg_buffer[2]);
 		goto fail;
@@ -721,7 +721,7 @@ int sfd = -1;
 	}
 
 	/* search for the IP and the session ID in all procs */
-	now = time(0);
+	now = time(NULL);
 
 	if (match_ip_only == 0) {
 		proc_to_send = proc_search_dtls_id(s, session_id, session_id_size);
@@ -779,7 +779,7 @@ int sfd = -1;
 
 		ret = send_socket_msg_to_worker(s, proc_to_send, CMD_UDP_FD,
 			sfd,
-			&msg, 
+			&msg,
 			(pack_size_func)udp_fd_msg__get_packed_size,
 			(pack_func)udp_fd_msg__pack);
 		if (ret < 0) {
@@ -902,7 +902,7 @@ static void kill_children_auth_timeout(main_server_st* s)
 	list_for_each_safe(&s->proc_list.head, ctmp, cpos, list) {
 		/* If the worker has not completed it's auth within auth_timeout seconds, kill it */
 		if ((ctmp->status < PS_AUTH_COMPLETED) &&
-		    (ctmp->conn_time < oldest_permitted_session) && 
+		    (ctmp->conn_time < oldest_permitted_session) &&
 			(ctmp->pid != -1)) {
 			remove_proc(s, ctmp, RPROC_KILL);
 		}
@@ -944,7 +944,7 @@ static void term_sig_watcher_cb(struct ev_loop *loop, ev_signal *w, int revents)
 	if (server_drain_ms == 0) {
 		terminate_server(s);
 	}
-	else 
+	else
 	{
 		if (!ev_is_active(&graceful_shutdown_watcher)) {
 			mslog(s, NULL, LOG_INFO, "termination request received; stopping new connections");
@@ -1079,6 +1079,7 @@ static void listen_watcher_cb (EV_P_ ev_io *w, int revents)
 		pid = fork();
 		if (pid == 0) {	/* child */
 			unsigned int sec_mod_instance_index;
+			char buf[MAX_IP_STR]; // buffer holding human readable sockaddr
 			/* close any open descriptors, and erase
 			 * sensitive data before running the worker
 			 */
@@ -1096,9 +1097,10 @@ static void listen_watcher_cb (EV_P_ ev_io *w, int revents)
 
 			set_self_oom_score_adj(s);
 
-			sec_mod_instance_index = hash_any(
-				SA_IN_P_GENERIC(&ws->remote_addr, ws->remote_addr_len),
-				SA_IN_SIZE(ws->remote_addr_len), 0) % s->sec_mod_instance_count;
+			sec_mod_instance_index = hash_any(&ws->remote_addr, ws->remote_addr_len, 0) % s->sec_mod_instance_count;
+			mslog(s, NULL, LOG_DEBUG, "map worker serving remote address %s to secmod instance %u",
+				human_addr((struct sockaddr*)&ws->remote_addr, ws->remote_addr_len, buf, sizeof(buf)),
+				sec_mod_instance_index);
 
 			/* write sec-mod's address */
 			memcpy(&ws->secmod_addr, &s->sec_mod_instances[sec_mod_instance_index].secmod_addr, s->sec_mod_instances[sec_mod_instance_index].secmod_addr_len);
@@ -1114,7 +1116,7 @@ static void listen_watcher_cb (EV_P_ ev_io *w, int revents)
 			set_cloexec_flag(fd, false);
 			ws->conn_fd = fd;
 			ws->conn_type = stype;
-			ws->session_start_time = time(0);
+			ws->session_start_time = time(NULL);
 
 			human_addr2((const struct sockaddr *)&ws->remote_addr, ws->remote_addr_len, ws->remote_ip_str, sizeof(ws->remote_ip_str), 0);
 			human_addr2((const struct sockaddr *)&ws->our_addr, ws->our_addr_len, ws->our_ip_str, sizeof(ws->our_ip_str), 0);
@@ -1126,13 +1128,13 @@ static void listen_watcher_cb (EV_P_ ev_io *w, int revents)
 			hmac_components[2].data = &ws->session_start_time;
 			hmac_components[2].length = sizeof(ws->session_start_time);
 
-			generate_hmac(sizeof(s->hmac_key), s->hmac_key, sizeof(hmac_components) / sizeof(hmac_components[0]), hmac_components, (uint8_t*) ws->sec_auth_init_hmac);
-			
+			generate_hmac(sizeof(s->hmac_key), s->hmac_key, ARRAY_SIZE(hmac_components), hmac_components, (uint8_t*) ws->sec_auth_init_hmac);
+
 			// Clear the HMAC key
 			safe_memset((uint8_t*)s->hmac_key, 0, sizeof(s->hmac_key));
 
 			if (!set_env_from_ws(s))
-				exit(1);
+				exit(EXIT_FAILURE);
 
 #if defined(PROC_FS_SUPPORTED)
 			{
@@ -1141,18 +1143,18 @@ static void listen_watcher_cb (EV_P_ ev_io *w, int revents)
 				path_length = readlink("/proc/self/exe", path, sizeof(path)-1);
 				if (path_length == -1) {
 					mslog(s, NULL, LOG_ERR, "readlink failed %s", strerror(ret));
-					exit(1);
+					exit(EXIT_FAILURE);
 				}
 				path[path_length] = '\0';
 				if (snprintf(worker_path, sizeof(worker_path), "%s-worker", path) >= sizeof(worker_path)) {
 					mslog(s, NULL, LOG_ERR, "snprint of path %s and ocserv-worker failed", path);
-					exit(1);
+					exit(EXIT_FAILURE);
 				}
 			}
 #else
 			if (snprintf(worker_path, sizeof(worker_path), "%s-worker", worker_argv[0]) >= sizeof(worker_path)) {
 				mslog(s, NULL, LOG_ERR, "snprint of path %s and ocserv-worker failed", worker_argv[0]);
-				exit(1);
+				exit(EXIT_FAILURE);
 			}
 #endif
 
@@ -1160,14 +1162,14 @@ static void listen_watcher_cb (EV_P_ ev_io *w, int revents)
 			execv(worker_path, worker_argv);
 			ret = errno;
 			mslog(s, NULL, LOG_ERR, "exec %s failed %s", worker_path, strerror(ret));
-			exit(1);
+			exit(EXIT_FAILURE);
 		} else if (pid == -1) {
 fork_failed:
 			mslog(s, NULL, LOG_ERR, "fork failed");
 			close(cmd_fd[0]);
 		} else { /* parent */
 			/* add_proc */
-			ctmp = new_proc(s, pid, cmd_fd[0], 
+			ctmp = new_proc(s, pid, cmd_fd[0],
 					&ws->remote_addr, ws->remote_addr_len,
 					&ws->our_addr, ws->our_addr_len,
 					ws->sid, sizeof(ws->sid));
@@ -1245,7 +1247,7 @@ static void perform_maintenance(main_server_st *s)
 	mslog(s, NULL, LOG_DEBUG, "performing maintenance");
 	cleanup_banned_entries(s);
 	clear_old_configs(s->vconfig);
-	
+
 	kill_children_auth_timeout(s);
 
 	list_for_each_rev(s->vconfig, vhost, list) {
@@ -1269,12 +1271,12 @@ static void latency_watcher_cb(EV_P_ ev_timer *w, int revents)
 	s->stats.delta_latency_stats.rms_total = 0;
 	s->stats.delta_latency_stats.sample_count = 0;
 	mslog(
-		s, 
-		NULL, 
-		LOG_DEBUG, 
-		"Latency: Median Total %ld RMS Total %ld Sample Count %ld", 
-		s->stats.current_latency_stats.median_total, 
-		s->stats.current_latency_stats.rms_total, 
+		s,
+		NULL,
+		LOG_DEBUG,
+		"Latency: Median Total %ld RMS Total %ld Sample Count %ld",
+		s->stats.current_latency_stats.median_total,
+		s->stats.current_latency_stats.rms_total,
 		s->stats.current_latency_stats.sample_count);
 }
 #endif
@@ -1324,28 +1326,28 @@ int main(int argc, char** argv)
 	main_pool = talloc_init("main");
 	if (main_pool == NULL) {
 		fprintf(stderr, "talloc init error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	config_pool = talloc_init("config");
 	if (config_pool == NULL) {
 		fprintf(stderr, "talloc init error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	if (snapshot_init(config_pool, &config_snapshot, "/tmp/ocserv_") < 0) {
 		fprintf(stderr, "failed to init snapshot");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	s = talloc_zero(main_pool, main_server_st);
 	if (s == NULL) {
 		fprintf(stderr, "memory error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 	s->main_pool = main_pool;
 	s->config_pool = config_pool;
-	s->stats.start_time = s->stats.last_reset = time(0);
+	s->stats.start_time = s->stats.last_reset = time(NULL);
 	s->top_fd = -1;
 	s->ctl_fd = -1;
 	s->netns.default_fd = -1;
@@ -1353,7 +1355,7 @@ int main(int argc, char** argv)
 
 	if (!hmac_init_key(sizeof(s->hmac_key), (uint8_t*)(s->hmac_key))) {
 		fprintf(stderr, "unable to generate hmac key\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	// getopt processing mutates argv. Save a copy to pass to the child.
@@ -1361,13 +1363,13 @@ int main(int argc, char** argv)
 	worker_argv = talloc_zero_array(main_pool, char*, worker_argc + 1);
 	if (!worker_argv) {
 		fprintf(stderr, "memory error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 	for (i = 0; i < argc; i ++) {
 		worker_argv[i] = talloc_strdup(main_pool, argv[i]);
 		if (!worker_argv[i]) {
 			fprintf(stderr, "memory error\n");
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 	}
 
@@ -1385,7 +1387,7 @@ int main(int argc, char** argv)
 	if (if_address_init(s) == 0)
 	{
 		fprintf(stderr, "failed to initialize local addresses\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	sigemptyset(&sig_default_set);
@@ -1399,32 +1401,32 @@ int main(int argc, char** argv)
 	s->vconfig = talloc_zero(config_pool, struct list_head);
 	if (s->vconfig == NULL) {
 		fprintf(stderr, "memory error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 	list_head_init(s->vconfig);
 
 	ret = cmd_parser(config_pool, argc, argv, s->vconfig, false);
 	if (ret < 0) {
 		fprintf(stderr, "Error in arguments\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	setproctitle(PACKAGE_NAME"-main");
 
 	if (getuid() != 0) {
 		fprintf(stderr, "This server requires root access to operate.\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	if (GETPCONFIG(s)->listen_netns_name && open_namespaces(&s->netns, GETPCONFIG(s)) < 0) {
 		fprintf(stderr, "cannot init listen namespaces\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 	/* Listen to network ports */
 	ret = listen_ports(s, GETPCONFIG(s), &s->listen_list, &s->netns);
 	if (ret < 0) {
 		fprintf(stderr, "Cannot listen to specified ports\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	flags = LOG_PID|LOG_NDELAY;
@@ -1443,7 +1445,7 @@ int main(int argc, char** argv)
 		if (daemon(GETPCONFIG(s)->no_chdir, 0) == -1) {
 			e = errno;
 			fprintf(stderr, "daemon failed: %s\n", strerror(e));
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 	}
 
@@ -1458,12 +1460,12 @@ int main(int argc, char** argv)
 
 	// Start the configured number of ocserv-sm processes
 	s->sec_mod_instance_count = GETPCONFIG(s)->sec_mod_scale;
-	
+
 	if (s->sec_mod_instance_count == 0)	{
 		if (GETCONFIG(s)->max_clients != 0) {
 			// Compute ideal number of clients per sec-mod
 			unsigned int sec_mod_count_for_users = GETCONFIG(s)->max_clients / MINIMUM_USERS_PER_SEC_MOD + 1;
-			// Limit it to number of processors. 
+			// Limit it to number of processors.
 			s->sec_mod_instance_count = MIN(processor_count,sec_mod_count_for_users);
 		} else {
 			// If it's unlimited, the use processor count.
@@ -1483,13 +1485,13 @@ int main(int argc, char** argv)
 	ret = ctl_handler_init(s);
 	if (ret < 0) {
 		mslog(s, NULL, LOG_ERR, "Cannot create command handler");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	main_loop = EV_DEFAULT;
 	if (main_loop == NULL) {
 		mslog(s, NULL, LOG_ERR, "could not initialise libev");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	mslog(s, NULL, LOG_INFO, "initialized %s", PACKAGE_STRING);
@@ -1500,7 +1502,7 @@ int main(int argc, char** argv)
 		if (chdir(GETPCONFIG(s)->chroot_dir) != 0) {
 			e = errno;
 			mslog(s, NULL, LOG_ERR, "cannot chdir to %s: %s", GETPCONFIG(s)->chroot_dir, strerror(e));
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 	}
 	ms_sleep(100); /* give some time for sec-mod to initialize */
@@ -1518,13 +1520,13 @@ int main(int argc, char** argv)
 	worker_pool = talloc_named(main_pool, 0, "worker");
 	if (worker_pool == NULL) {
 		mslog(s, NULL, LOG_ERR, "talloc init error");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	s->ws = talloc_zero(worker_pool, struct worker_st);
 	if (s->ws == NULL) {
 		mslog(s, NULL, LOG_ERR, "memory error");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 #ifdef HAVE_GSSAPI
@@ -1532,7 +1534,7 @@ int main(int argc, char** argv)
 	ret = asn1_array2tree(kkdcp_asn1_tab, &_kkdcp_pkix1_asn, NULL);
 	if (ret != ASN1_SUCCESS) {
 		mslog(s, NULL, LOG_ERR, "KKDCP ASN.1 initialization error");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 #endif
 
@@ -1603,7 +1605,7 @@ int main(int argc, char** argv)
 	/* Main server loop */
 	ev_run (main_loop, 0);
 
-	/* try to clean-up everything allocated to ease checks 
+	/* try to clean-up everything allocated to ease checks
 	 * for memory leaks.
 	 */
 	for (i = 0; i < s->sec_mod_instance_count; i ++) {
@@ -1616,7 +1618,7 @@ int main(int argc, char** argv)
 
 	if (GETPCONFIG(s)->listen_netns_name && close_namespaces(&s->netns) < 0) {
 		fprintf(stderr, "cannot close listen namespaces\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 	clear_lists(s);
 	clear_vhosts(s->vconfig);
