@@ -273,10 +273,10 @@ static int handle_reset_cmd(CONN_TYPE * conn, const char *arg, cmd_params_st *pa
 
 static int handle_exit_cmd(CONN_TYPE * conn, const char *arg, cmd_params_st *params)
 {
-	exit(0);
+	exit(EXIT_SUCCESS);
 }
 
-/* checks whether an input command of type "  list   users" matches 
+/* checks whether an input command of type "  list   users" matches
  * the given cmd (e.g., "list users"). If yes it executes func() and returns true.
  */
 static
@@ -321,7 +321,7 @@ unsigned check_cmd(const char *cmd, const char *input,
 
 		if (need_preconn != 0) {
 			if (conn_prehandle(conn) < 0) {
-			 	*status = 1;
+				*status = 1;
 			} else {
 				*status = func(conn, p, params);
 			}
@@ -410,7 +410,7 @@ static char *merge_args(int argc, char **argv)
 	data = malloc(size);
 	if (data == NULL) {
 		fprintf(stderr, "memory error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	p = data;
@@ -565,7 +565,7 @@ int main(int argc, char **argv)
 	gl_pool = talloc_init("occtl");
 	if (gl_pool == NULL) {
 		fprintf(stderr, "talloc init error\n");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	ocsignal(SIGPIPE, SIG_IGN);
@@ -597,7 +597,7 @@ int main(int argc, char **argv)
 			} else if (argv[1][1] == 'v'
 			    || (argv[1][1] == '-' && argv[1][2] == 'v')) {
 				version();
-				exit(0);
+				exit(EXIT_SUCCESS);
 			} else if (argc > 2 && (argv[1][1] == 's'
 			    || (argv[1][1] == '-' && argv[1][2] == 's'))) {
 				file = talloc_strdup(gl_pool, argv[2]);
@@ -611,11 +611,11 @@ int main(int argc, char **argv)
 				argc -= 2;
 			} else {
 				usage();
-				exit(0);
+				exit(EXIT_SUCCESS);
 			}
-  		}
+		}
 
-  		/* handle all arguments as a command */
+		/* handle all arguments as a command */
 		ret = single_cmd(argc, argv, gl_pool, file, &params);
 		talloc_free(gl_pool);
 		exit(ret);
