@@ -45,7 +45,7 @@
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <assert.h>
-#include "hex.h"
+#include <ccan/str/hex/hex.h>
 #include "geoip.h"
 #include <vpn.h>
 #include <base64-helper.h>
@@ -67,7 +67,7 @@ struct unix_ctx {
 	const char *socket_file;
 };
 
-static uint8_t msg_map[] = {   
+static uint8_t msg_map[] = {
         [CTL_CMD_STATUS] = CTL_CMD_STATUS_REP,
         [CTL_CMD_RELOAD] = CTL_CMD_RELOAD_REP,
         [CTL_CMD_STOP] = CTL_CMD_STOP_REP,
@@ -184,7 +184,7 @@ int connect_to_ocserv (const char *socket_file)
 	ret = connect(sd, (struct sockaddr *)&sa, sizeof(sa));
 	if (ret == -1) {
 		e = errno;
-		fprintf(stderr, "error connecting to ocserv socket '%s': %s\n", 
+		fprintf(stderr, "error connecting to ocserv socket '%s': %s\n",
 			sa.sun_path, strerror(e));
 		ret = -1;
 		goto error;
@@ -239,13 +239,13 @@ int handle_status_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 
 		t = rep->start_time;
 		tm = localtime_r(&t, &_tm);
-		print_time_ival7(buf, time(0), t);
+		print_time_ival7(buf, time(NULL), t);
 		strftime(str_since, sizeof(str_since), DATE_TIME_FMT, tm);
 
 		print_single_value_ex(stdout, params, "Up since", str_since, buf, 1);
 		if (HAVE_JSON(params)) {
 			print_single_value_int(stdout, params, "raw_up_since", rep->start_time, 1);
-			print_single_value_int(stdout, params, "uptime", ((long)time(0)) - ((long)rep->start_time), 1);
+			print_single_value_int(stdout, params, "uptime", ((long)time(NULL)) - ((long)rep->start_time), 1);
 		}
 		print_single_value_int(stdout, params, "Active sessions", rep->active_clients, 1);
 		print_single_value_int(stdout, params, "Total sessions", rep->total_sessions_closed, 1);
@@ -267,12 +267,12 @@ int handle_status_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 
 			time2human(median_latency, buf, sizeof(buf));
 			print_single_value(stdout, params, "Median latency", buf, 1);
-			if (HAVE_JSON(params)) 
+			if (HAVE_JSON(params))
 				print_single_value_int(stdout, params, "raw_median_latency", median_latency, 1);
 
 			time2human(stdev_latency, buf, sizeof(buf));
 			print_single_value(stdout, params, "STDEV latency", buf, 1);
-			if (HAVE_JSON(params)) 
+			if (HAVE_JSON(params))
 				print_single_value_int(stdout, params, "raw_stdev_latency", stdev_latency, 1);
 
 		}
@@ -285,7 +285,7 @@ int handle_status_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 		t = rep->last_reset;
 		if (t > 0) {
 			tm = localtime_r(&t, &_tm);
-			print_time_ival7(buf, time(0), t);
+			print_time_ival7(buf, time(NULL), t);
 			strftime(str_since, sizeof(str_since), DATE_TIME_FMT, tm);
 
 			print_single_value_ex(stdout, params, "Last stats reset", str_since, buf, 1);
@@ -347,7 +347,7 @@ int handle_status_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 	ret = 1;
 
  cleanup:
- 	free_reply(&raw);
+	free_reply(&raw);
 	return ret;
 }
 
@@ -358,7 +358,7 @@ int handle_reload_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 	BoolMsg *rep;
 	unsigned status;
 	PROTOBUF_ALLOCATOR(pa, ctx);
-	
+
 	init_reply(&raw);
 
 	ret = send_cmd(ctx, CTL_CMD_RELOAD, NULL, NULL, NULL, &raw);
@@ -374,7 +374,7 @@ int handle_reload_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 	bool_msg__free_unpacked(rep, &pa);
 
 	if (status != 0)
-        	printf("Server scheduled to reload\n");
+		printf("Server scheduled to reload\n");
 	else
 		goto error_status;
 
@@ -398,7 +398,7 @@ int handle_stop_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *params
 	BoolMsg *rep;
 	unsigned status;
 	PROTOBUF_ALLOCATOR(pa, ctx);
-	
+
 	init_reply(&raw);
 
 	ret = send_cmd(ctx, CTL_CMD_STOP, NULL, NULL, NULL, &raw);
@@ -414,7 +414,7 @@ int handle_stop_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *params
 	bool_msg__free_unpacked(rep, &pa);
 
 	if (status != 0)
-        	printf("Server scheduled to stop\n");
+		printf("Server scheduled to stop\n");
 	else
 		goto error_status;
 
@@ -446,7 +446,7 @@ int handle_unban_ip_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *pa
 		check_cmd_help(rl_line_buffer);
 		return 1;
 	}
-	
+
 	init_reply(&raw);
 
 	/* convert the IP to the simplest form */
@@ -468,8 +468,8 @@ int handle_unban_ip_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *pa
 		return 1;
 	}
 
-	ret = send_cmd(ctx, CTL_CMD_UNBAN_IP, &req, 
-		(pack_size_func)unban_req__get_packed_size, 
+	ret = send_cmd(ctx, CTL_CMD_UNBAN_IP, &req,
+		(pack_size_func)unban_req__get_packed_size,
 		(pack_func)unban_req__pack, &raw);
 	if (ret < 0) {
 		goto error;
@@ -514,13 +514,13 @@ int handle_disconnect_user_cmd(struct unix_ctx *ctx, const char *arg, cmd_params
 		check_cmd_help(rl_line_buffer);
 		return 1;
 	}
-	
+
 	init_reply(&raw);
 
 	req.username = (void*)arg;
 
-	ret = send_cmd(ctx, CTL_CMD_DISCONNECT_NAME, &req, 
-		(pack_size_func)username_req__get_packed_size, 
+	ret = send_cmd(ctx, CTL_CMD_DISCONNECT_NAME, &req,
+		(pack_size_func)username_req__get_packed_size,
 		(pack_func)username_req__pack, &raw);
 	if (ret < 0) {
 		goto error;
@@ -569,13 +569,13 @@ int handle_disconnect_id_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_s
 		check_cmd_help(rl_line_buffer);
 		return 1;
 	}
-	
+
 	init_reply(&raw);
 
 	req.id = id;
 
-	ret = send_cmd(ctx, CTL_CMD_DISCONNECT_ID, &req, 
-		(pack_size_func)id_req__get_packed_size, 
+	ret = send_cmd(ctx, CTL_CMD_DISCONNECT_ID, &req,
+		(pack_size_func)id_req__get_packed_size,
 		(pack_func)id_req__pack, &raw);
 	if (ret < 0) {
 		goto error;
@@ -657,7 +657,7 @@ void common_user_list(struct unix_ctx *ctx, UserListRep *rep, FILE *out, cmd_par
 		tm = localtime_r(&t, &_tm);
 		strftime(str_since, sizeof(str_since), DATE_TIME_FMT, tm);
 
-		print_time_ival7(tmpbuf, time(0), t);
+		print_time_ival7(tmpbuf, time(NULL), t);
 
 		fprintf(out, "%8d %8s %8s %14s %14s %6s ",
 			(int)rep->user[i]->id, username, rep->user[i]->vhost, rep->user[i]->ip, vpn_ip, rep->user[i]->tun);
@@ -761,7 +761,7 @@ void session_list(struct unix_ctx *ctx, SecmListCookiesReplyMsg *rep, FILE *out,
 		if (t > 0) {
 			tm = localtime_r(&t, &_tm);
 			strftime(str_since, sizeof(str_since), DATE_TIME_FMT, tm);
-			print_time_ival7(tmpbuf, time(0), t);
+			print_time_ival7(tmpbuf, time(NULL), t);
 		}
 
 		sid = shorten(rep->cookies[i]->safe_id.data, rep->cookies[i]->safe_id.len, 1);
@@ -1020,7 +1020,7 @@ int handle_list_banned_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st
 			}
 			print_start_block(out, params);
 
-			print_time_ival7(tmpbuf, t, time(0));
+			print_time_ival7(tmpbuf, t, time(NULL));
 
 			if (HAVE_JSON(params)) {
 				print_single_value(out, params, "IP", txt_ip, 1);
@@ -1179,7 +1179,7 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 
 		print_single_value(out, params, "Hostname", args->user[i]->hostname, 1);
 
-		print_time_ival7(tmpbuf, time(0), t);
+		print_time_ival7(tmpbuf, time(NULL), t);
 		print_single_value_ex(out, params, "Connected at", str_since, tmpbuf, 1);
 
 		if (HAVE_JSON(params)) {
@@ -1340,7 +1340,7 @@ int session_info_cmd(void *ctx, SecmListCookiesReplyMsg * args, FILE *out,
 			print_single_value_int(out, params, "in_use", args->cookies[i]->in_use, 1);
 		} else {
 			/* old names for compatibility */
-			print_pair_value(out, params, "In use", args->cookies[i]->in_use?"True":"False", 
+			print_pair_value(out, params, "In use", args->cookies[i]->in_use?"True":"False",
 					 "Activated", args->cookies[i]->session_is_open?"True":"False", 1);
 			print_single_value(out, params, "Certificate auth", args->cookies[i]->tls_auth_ok?"True":"False", 1);
 		}
@@ -1394,8 +1394,8 @@ int handle_show_user_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *p
 
 	req.username = (void*)arg;
 
-	ret = send_cmd(ctx, CTL_CMD_USER_INFO, &req, 
-		(pack_size_func)username_req__get_packed_size, 
+	ret = send_cmd(ctx, CTL_CMD_USER_INFO, &req,
+		(pack_size_func)username_req__get_packed_size,
 		(pack_func)username_req__pack, &raw);
 	if (ret < 0) {
 		goto error;
@@ -1448,7 +1448,7 @@ int handle_events_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 
 	init_reply(&raw);
 
-	ret = send_cmd(ctx, CTL_CMD_TOP, NULL, 0, 0, &raw); 
+	ret = send_cmd(ctx, CTL_CMD_TOP, NULL, 0, 0, &raw);
 	if (ret < 0) {
 		goto error;
 	}
@@ -1568,7 +1568,7 @@ int handle_events_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 
 				entries_add(ctx, rep2->user->user[0]->username, strlen(rep2->user->user[0]->username), rep2->user->user[0]->id);
 			} else {
-				print_time_ival7(tmpbuf, time(0), rep2->user->user[0]->conn_time);
+				print_time_ival7(tmpbuf, time(NULL), rep2->user->user[0]->conn_time);
 				printf("%s: disconnect user '%s' (%u) from %s with IP %s (reason: %s, time: %s)\n",
 					rep2->user->user[0]->vhost,
 					rep2->user->user[0]->username,
@@ -1628,8 +1628,8 @@ int handle_show_id_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *par
 
 	req.id = id;
 
-	ret = send_cmd(ctx, CTL_CMD_ID_INFO, &req, 
-		(pack_size_func)id_req__get_packed_size, 
+	ret = send_cmd(ctx, CTL_CMD_ID_INFO, &req,
+		(pack_size_func)id_req__get_packed_size,
 		(pack_func)id_req__pack, &raw);
 	if (ret < 0) {
 		goto error;
