@@ -51,7 +51,7 @@ int ret, status = 0;
 		ret = execl("/bin/sh", "sh", "-c", cmd, NULL);
 		if (ret == -1) {
 			mslog(s, proc, LOG_ERR, "Could not execute route script %s", cmd);
-			exit(1);
+			exit(EXIT_FAILURE);
 		}
 
 		exit(77);
@@ -80,8 +80,8 @@ int ret, status = 0;
 }
 
 static
-int replace_cmd(struct main_server_st* s, proc_st *proc, 
-		char **cmd, const char* pattern, 
+int replace_cmd(struct main_server_st* s, proc_st *proc,
+		char **cmd, const char* pattern,
 		const char* route, const char* dev)
 {
 	str_st str;
@@ -140,7 +140,7 @@ char *cmd = NULL;
 
 	ret = 0;
  fail:
- 	talloc_free(cmd);
+	talloc_free(cmd);
 	return ret;
 }
 
@@ -156,7 +156,7 @@ int route_del(struct main_server_st* s, proc_st *proc, const char* route, const
 	return route_adddel(s, proc, GETCONFIG(s)->route_del_cmd, route, dev);
 }
 
-/* Executes the commands required to apply all the configured routes 
+/* Executes the commands required to apply all the configured routes
  * for this client locally.
  */
 int apply_iroutes(struct main_server_st* s, struct proc_st *proc)
@@ -175,14 +175,14 @@ int ret;
 	proc->applied_iroutes = 1;
 
 	return 0;
-fail:
+ fail:
 	for (j=0;j<i;j++)
 		route_del(s, proc, proc->config->iroutes[j], proc->tun_lease.name);
 
 	return -1;
 }
 
-/* Executes the commands required to removed all the configured routes 
+/* Executes the commands required to removed all the configured routes
  * for this client.
  */
 void remove_iroutes(struct main_server_st* s, struct proc_st *proc)
@@ -199,4 +199,3 @@ unsigned i;
 
 	return;
 }
-
