@@ -43,7 +43,7 @@
 int response_404(worker_st *ws, unsigned http_ver)
 {
 	if (cstp_printf(ws, "HTTP/1.%u 404 Not found\r\n", http_ver) < 0 ||
-	    cstp_printf(ws, "Content-length: %u\r\n", (unsigned)(sizeof(HTML_404) - 1)) < 0 ||
+	    cstp_printf(ws, "Content-Length: %u\r\n", (unsigned)(sizeof(HTML_404) - 1)) < 0 ||
 	    cstp_puts  (ws, "Connection: close\r\n\r\n") < 0 ||
 	    cstp_puts  (ws, HTML_404) < 0)
 		return -1;
@@ -223,7 +223,7 @@ int get_config_handler(worker_st *ws, unsigned http_ver)
 	int ret;
 	struct stat st;
 
-	oclog(ws, LOG_HTTP_DEBUG, "requested config: %s", ws->req.url); 
+	oclog(ws, LOG_HTTP_DEBUG, "requested config: %s", ws->req.url);
 
 	cookie_authenticate_or_exit(ws);
 
@@ -232,7 +232,7 @@ int get_config_handler(worker_st *ws, unsigned http_ver)
 		response_404(ws, http_ver);
 		return -1;
 	}
-	
+
 	ret = stat(ws->user_config->xml_config_file, &st);
 	if (ret == -1) {
 		oclog(ws, LOG_INFO, "cannot load config file '%s'", ws->user_config->xml_config_file);
@@ -259,7 +259,7 @@ int get_config_handler(worker_st *ws, unsigned http_ver)
 
 int get_string_handler(worker_st *ws, unsigned http_ver)
 {
-	oclog(ws, LOG_HTTP_DEBUG, "requested fixed string: %s", ws->req.url); 
+	oclog(ws, LOG_HTTP_DEBUG, "requested fixed string: %s", ws->req.url);
 	if (!strcmp(ws->req.url, "/1/binaries/update.txt")) {
 		return send_data(ws, http_ver, "text/xml", VPN_VERSION,
 				   sizeof(VPN_VERSION) - 1);
@@ -274,7 +274,7 @@ int get_string_handler(worker_st *ws, unsigned http_ver)
 
 int get_dl_handler(worker_st *ws, unsigned http_ver)
 {
-	oclog(ws, LOG_HTTP_DEBUG, "requested downloader: %s", ws->req.url); 
+	oclog(ws, LOG_HTTP_DEBUG, "requested downloader: %s", ws->req.url);
 	return send_data(ws, http_ver, "application/x-shellscript", SH_SCRIPT,
 			   sizeof(SH_SCRIPT) - 1);
 }
@@ -288,4 +288,3 @@ int get_empty_handler(worker_st *ws, unsigned http_ver)
 }
 
 #endif
-
