@@ -241,9 +241,7 @@ unsigned switch_comp_priority(void *pool, const char *modstring)
 		ret = 0;
 		goto finish;
 	}
-	for (i = 0;
-	     i < sizeof(comp_methods) / sizeof(comp_methods[0]);
-	     i++) {
+	for (i = 0; i < ARRAY_SIZE(comp_methods); i++) {
 		if (c_strcasecmp(algo, comp_methods[i].name) == 0) {
 			comp_methods[i].server_prio = priority;
 			ret = 1;
@@ -419,6 +417,12 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 		} else if (strncasecmp(req->user_agent, "AnyConnect", 10) == 0) {
 			oclog(ws, LOG_DEBUG, "Detected Cisco AnyConnect");
 			req->user_agent_type = AGENT_ANYCONNECT;
+		} else if (strncasecmp(req->user_agent, "Clavister OneConnect VPN", 24) == 0) {
+			oclog(ws, LOG_DEBUG, "Detected Clavister OneConnect");
+			req->user_agent_type = AGENT_OPENCONNECT_CLAVISTER;
+		} else if (strncasecmp(req->user_agent, "AnyLink Secure Client", 21) == 0) {
+			oclog(ws, LOG_DEBUG, "Detected AnyLink");
+			req->user_agent_type = AGENT_ANYLINK;
 		} else {
 			oclog(ws, LOG_DEBUG, "Unknown client (%s)", req->user_agent);
 		}
@@ -453,9 +457,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 		}
 
 		while ((token = strtok(str, ":")) != NULL) {
-			for (i = 0;
-			     i < sizeof(ciphersuites) / sizeof(ciphersuites[0]);
-			     i++) {
+			for (i = 0; i < ARRAY_SIZE(ciphersuites); i++) {
 				if (strcmp(token, ciphersuites[i].oc_name) == 0) {
 					if (cand == NULL ||
 					    cand->server_prio < ciphersuites[i].server_prio ||
@@ -520,9 +522,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 		}
 
 		while ((token = strtok(str, ":")) != NULL) {
-			for (i = 0;
-			     i < sizeof(ciphersuites12) / sizeof(ciphersuites12[0]);
-			     i++) {
+			for (i = 0; i < ARRAY_SIZE(ciphersuites12); i++) {
 				if (strcmp(token, ciphersuites12[i].oc_name) == 0) {
 					if (cand == NULL ||
 					    cand->server_prio < ciphersuites12[i].server_prio ||
@@ -553,20 +553,18 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 #ifdef ENABLE_COMPRESSION
 	case HEADER_DTLS_ENCODING:
 	case HEADER_CSTP_ENCODING:
-	        if (WSCONFIG(ws)->enable_compression == 0)
-	        	break;
+		if (WSCONFIG(ws)->enable_compression == 0)
+			break;
 
 		if (req->next_header == HEADER_DTLS_ENCODING)
 			selected_comp = &ws->dtls_selected_comp;
 		else
 			selected_comp = &ws->cstp_selected_comp;
-	        *selected_comp = NULL;
+		*selected_comp = NULL;
 
 		str = (char *)value;
 		while ((token = strtok(str, ",")) != NULL) {
-			for (i = 0;
-			     i < sizeof(comp_methods) / sizeof(comp_methods[0]);
-			     i++) {
+			for (i = 0; i < ARRAY_SIZE(comp_methods); i++) {
 				if (c_strcasecmp(token, comp_methods[i].name) == 0) {
 					if (comp_cand == NULL ||
 					    comp_cand->server_prio <
@@ -873,19 +871,15 @@ void http_req_deinit(worker_st * ws)
  */
 int add_owasp_headers(worker_st * ws)
 {
-	if (cstp_puts(ws, "Strict-Transport-Security: max-age=31536000 ; includeSubDomains\r\n") < 0 ||
-		cstp_puts(ws, "X-Frame-Options: deny\r\n") < 0 ||
-		cstp_puts(ws, "X-Content-Type-Options: nosniff\r\n") < 0 ||
-		cstp_puts(ws, "Content-Security-Policy: default-src \'none\'\r\n") < 0 ||
-		cstp_puts(ws, "X-Permitted-Cross-Domain-Policies: none\r\n") < 0 ||
-		cstp_puts(ws, "Referrer-Policy: no-referrer\r\n") < 0 ||
-		cstp_puts(ws, "Clear-Site-Data: \"cache\",\"cookies\",\"storage\"\r\n") < 0 ||
-		cstp_puts(ws, "Cross-Origin-Embedder-Policy: require-corp\r\n") < 0 ||
-		cstp_puts(ws, "Cross-Origin-Opener-Policy: same-origin\r\n") < 0 ||
-		cstp_puts(ws, "Cross-Origin-Resource-Policy: same-origin\r\n") < 0 ||
-		cstp_puts(ws, "X-XSS-Protection: 0\r\n") < 0)
+	unsigned i;
+
+	for(i=0; i < GETCONFIG(ws)->included_http_headers_size; i++)
 	{
-		return -1;
+		if (cstp_printf(ws, "%s", GETCONFIG(ws)->included_http_headers[i]) < 0 ||
+		    cstp_puts(ws, "\r\n") < 0)
+		{
+			return -1;
+		}
 	}
 	return 0;
 }
