@@ -73,10 +73,10 @@ static unsigned recv_from_new_fd(struct worker_st * ws, struct dtls_st *dtls, in
 
 	ret = 0;
  revert:
- 	*tmsg = dtls->dtls_tptr.msg;
- 	dtls->dtls_tptr.fd = saved_fd;
- 	dtls->dtls_tptr.msg = saved_tmsg;
- 	return ret;
+	*tmsg = dtls->dtls_tptr.msg;
+	dtls->dtls_tptr.fd = saved_fd;
+	dtls->dtls_tptr.msg = saved_tmsg;
+	return ret;
 }
 
 int handle_commands_from_main(struct worker_st *ws)
@@ -164,7 +164,7 @@ int handle_commands_from_main(struct worker_st *ws)
 				set_mtu_disc(fd, ws->proto, 0);
 
 			oclog(ws, LOG_DEBUG, "received new UDP fd and connected to peer");
-			ws->udp_recv_time = time(0);
+			ws->udp_recv_time = time(NULL);
 
 			return 0;
 
@@ -180,7 +180,7 @@ int handle_commands_from_main(struct worker_st *ws)
 }
 
 /* Completes the VPN device information.
- * 
+ *
  * Returns 0 on success.
  */
 int complete_vpn_info(worker_st * ws, struct vpn_st *vinfo)
@@ -227,19 +227,19 @@ void ocsigaltstack(struct worker_st *ws)
 	if (posix_memalign((void**)&ss.ss_sp, getpagesize(), SIGSTKSZ) != 0) {
 		oclog(ws, LOG_ERR,
 		      "could not allocate memory for signal stack");
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 	if (mprotect(ss.ss_sp, SIGSTKSZ, PROT_READ|PROT_WRITE) == -1) {
 		e = errno;
 		oclog(ws, LOG_ERR, "mprotect: %s\n", strerror(e));
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 	ss.ss_size = SIGSTKSZ;
 	ss.ss_flags = 0;
 	if (sigaltstack(&ss, NULL) == -1) {
 		e = errno;
 		oclog(ws, LOG_ERR, "sigaltstack: %s\n", strerror(e));
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 #endif
 }
