@@ -128,7 +128,7 @@ static void handle_alarm(int signo)
 	if (global_ws)
 		exit_worker_reason(global_ws, terminate_reason);
 
-	_exit(1);
+	_exit(EXIT_FAILURE);
 }
 
 static void handle_term(int signo)
@@ -486,7 +486,7 @@ void ws_add_score_to_ip(worker_st *ws, unsigned points, unsigned final, unsigned
 
 	if (final ==0 && reply->reply != AUTH__REP__OK) {
 		/* we have exceeded the maximum score */
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	ban_ip_reply_msg__free_unpacked(reply, &pa);
@@ -521,7 +521,7 @@ void send_stats_to_secmod(worker_st * ws, time_t now, unsigned discon_reason)
 		}
 
 		msg.remote_ip = human_addr2((void *)&ws->remote_addr, ws->remote_addr_len,
-		       		     buf, sizeof(buf), 0);
+					    buf, sizeof(buf), 0);
 
 		msg.ipv4 = ws->vinfo.ipv4;
 		msg.ipv6 = ws->vinfo.ipv6;
@@ -562,7 +562,7 @@ void exit_worker_reason(worker_st * ws, unsigned reason)
 {
 	/* send statistics to parent */
 	if (ws->auth_state == S_AUTH_COMPLETE) {
-		send_stats_to_secmod(ws, time(0), reason);
+		send_stats_to_secmod(ws, time(NULL), reason);
 	}
 
 	if (ws->ban_points > 0)
@@ -570,7 +570,7 @@ void exit_worker_reason(worker_st * ws, unsigned reason)
 
 	talloc_free(ws->main_pool);
 	closelog();
-	_exit(1);
+	_exit(EXIT_FAILURE);
 }
 
 #define HANDSHAKE_SESSION_ID_POS (34)
@@ -1285,7 +1285,7 @@ int periodic_check(worker_st * ws, struct timespec *tnow, unsigned dpd)
 	/* check DPD. Otherwise exit */
 	if (DTLS_ACTIVE(ws)->udp_state == UP_ACTIVE &&
 	    now - ws->last_msg_udp > DPD_TRIES * dpd && dpd > 0) {
-	    	unsigned data_mtu = DATA_MTU(ws, ws->link_mtu);
+		unsigned data_mtu = DATA_MTU(ws, ws->link_mtu);
 		oclog(ws, LOG_NOTICE,
 		      "have not received any UDP message or DPD for long (%d secs, DPD is %d)",
 		      (int)(now - ws->last_msg_udp), dpd);
@@ -1512,7 +1512,7 @@ static int dtls_mainloop(worker_st * ws, struct dtls_st * dtls, struct timespec
 
 	ret = 0;
  cleanup:
- 	packet_deinit(packet);
+	packet_deinit(packet);
 	return ret;
 }
 
@@ -1577,7 +1577,7 @@ static int tls_mainloop(struct worker_st *ws, struct timespec *tnow)
 
 	ret = 0;
  cleanup:
- 	packet_deinit(packet);
+	packet_deinit(packet);
 	return ret;
 }
 
@@ -1652,7 +1652,7 @@ static int tun_mainloop(struct worker_st *ws, struct timespec *tnow)
 			cstp_type = AC_PKT_COMPRESSED;
 		}
 	}
-#endif 
+#endif
 
 	/* only transmit if allowed */
 	if (bandwidth_update(&ws->b_tx, dtls_to_send.size, tnow)
@@ -1873,7 +1873,7 @@ static int connect_handler(worker_st * ws)
 	unsigned rnd;
 	unsigned i;
 	unsigned ip6;
-	time_t now = time(0);
+	time_t now = time(NULL);
 
 	ret = gnutls_rnd(GNUTLS_RND_NONCE, &rnd, sizeof(rnd));
 	if (ret < 0) {
@@ -2060,9 +2060,19 @@ static int connect_handler(worker_st * ws)
 	if (ws->full_ipv6 == 0) {
 		req->no_ipv6 = 1;
 		oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because IPv6 support was not requested.");
-	} else if (req->user_agent_type != AGENT_OPENCONNECT && req->user_agent_type != AGENT_ANYCONNECT) {
-		req->no_ipv6 = 1;
-		oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because the agent is not known.");
+	} else {
+		switch (req->user_agent_type) {
+			case AGENT_OPENCONNECT:
+			case AGENT_ANYCONNECT:
+			case AGENT_OPENCONNECT_CLAVISTER:
+			case AGENT_ANYLINK:
+				break;
+			case AGENT_OPENCONNECT_V3:
+			case AGENT_UNKNOWN:
+			default:
+				req->no_ipv6 = 1;
+				oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because the agent is not known.");
+		}
 	}
 
 	for (i = 0; i < ws->user_config->n_dns; i++) {
@@ -2624,9 +2634,9 @@ static int test_for_tcp_health_probe(struct worker_st *ws)
 	ret = recv(ws->conn_fd, buffer, sizeof(buffer), MSG_PEEK);
 
 	// If we get back an error, assume this was a tcp health probe
-	if (ret > 0) 
+	if (ret > 0)
 		return 0;
-	else 
+	else
 		return 1;
 }
 
@@ -2637,7 +2647,7 @@ static void syserr_cb (const char *msg)
 
 	oclog(ws, LOG_ERR, "libev fatal error: %s / %s", msg, strerror(err));
 
-  	terminate_reason = REASON_ERROR;
+	terminate_reason = REASON_ERROR;
 	exit_worker_reason(ws, terminate_reason);
 }
 
@@ -2743,7 +2753,7 @@ static void term_sig_watcher_cb(struct ev_loop *loop, ev_signal *w, int revents)
 
 static void invoke_dtls_if_needed(struct dtls_st * dtls)
 {
-	if ((dtls->udp_state > UP_WAIT_FD) && 
+	if ((dtls->udp_state > UP_WAIT_FD) &&
 		(dtls->dtls_session != NULL) &&
 		(gnutls_record_check_pending(dtls->dtls_session))) {
 		ev_invoke(worker_loop, &dtls->io, EV_READ);
@@ -2789,7 +2799,7 @@ static int worker_event_loop(struct worker_st * ws)
 	ocsignal(SIGTERM, SIG_DFL);
 	ocsignal(SIGINT, SIG_DFL);
 	ocsignal(SIGALRM, SIG_DFL);
-	
+
 	ev_init(&alarm_sig_watcher, term_sig_watcher_cb);
 	ev_signal_set (&alarm_sig_watcher, SIGALRM);
 	ev_signal_start (worker_loop, &alarm_sig_watcher);
@@ -2801,7 +2811,7 @@ static int worker_event_loop(struct worker_st * ws)
 	ev_init (&term_sig_watcher, term_sig_watcher_cb);
 	ev_signal_set (&term_sig_watcher, SIGTERM);
 	ev_signal_start (worker_loop, &term_sig_watcher);
-	
+
 	ev_set_userdata (worker_loop, ws);
 	ev_set_syserr_cb(syserr_cb);
 
